"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var react_1 = require("react");
var getElementRect = function (element) {
    var _a = element.getBoundingClientRect(), height = _a.height, left = _a.left, top = _a.top, width = _a.width;
    return {
        height: height,
        left: left,
        top: top,
        width: width,
    };
};
/**
 * Will listen to the document resizing to see if an element has moved positions.
 * Not using ResizeObserver because of IE11 support.
 * @param element HTMLElement to watch when resizing.
 */
exports.useElementBox = function (element) {
    var _a = tslib_1.__read(react_1.useState(getElementRect(element)), 2), box = _a[0], setBox = _a[1];
    react_1.useEffect(function () {
        var onResize = function () {
            requestAnimationFrame(function () {
                setBox(getElementRect(element));
            });
        };
        window.addEventListener('resize', onResize);
        return function () {
            window.removeEventListener('resize', onResize);
        };
    }, [element]);
    return box;
};
exports.ElementBox = function (props) {
    var box = exports.useElementBox(props.element);
    return props.children(box);
};
//# sourceMappingURL=use-element-box.js.map